@@ -1,4 +1,4 @@
-/* $Id: actions.c,v 1.1.1.1 2011/03/03 14:43:09 imilh Exp $ */
+/* $Id: actions.c,v 1.2 2011/08/02 20:33:08 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -67,6 +67,7 @@ static void
 pkg_download(Deptreehead *installhead)
 {
 	FILE		*fp;
+	fetchIO		*f = NULL;
 	Pkgdeptree	*pinstall;
 	struct stat	st;
 	Dlfile		*dlpkg;
@@ -104,7 +105,7 @@ pkg_download(Deptreehead *installhead)
 		strlcat(pkg, pinstall->depname, sizeof(pkg));
 		strlcat(pkg, PKG_EXT, sizeof(pkg));
 
-		if ((dlpkg = download_file(pkg, NULL)) == NULL) {
+		if ((dlpkg = download_file(f, pkg, NULL)) == NULL) {
 			fprintf(stderr, MSG_PKG_NOT_AVAIL, pinstall->depname);
 			if (!check_yesno())
 				errx(EXIT_FAILURE, MSG_PKG_NOT_AVAIL,
