@@ -1,4 +1,4 @@
-/* $Id: depends.c,v 1.21 2011/01/30 10:28:09 imil Exp $ */
+/* $Id: depends.c,v 1.1.1.1 2011/03/03 14:43:12 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -187,6 +187,7 @@ show_direct_depends(const char *pkgname)
 	char		query[BUFSIZ];
 	Pkgdeptree	*pdp;
 	Deptreehead	deptreehead;
+	Pkglist		*mapplist;
 
 	if ((plisthead = rec_pkglist(REMOTE_PKGS_QUERY)) == NULL) {
 		printf("%s\n", MSG_EMPTY_AVAIL_PKGLIST);
@@ -205,7 +206,12 @@ show_direct_depends(const char *pkgname)
 		if (pkgindb_doquery(query, pdb_rec_direct_deps, &deptreehead) == 0) {
 			printf(MSG_DIRECT_DEPS_FOR, pkgname);
 			SLIST_FOREACH(pdp, &deptreehead, next) {
-				printf("\t%s\n", pdp->depname);
+				if (package_version && 
+					(mapplist = map_pkg_to_dep(plisthead, pdp->depname))
+					!= NULL)
+					printf("\t%s\n", mapplist->pkgname);
+				else
+					printf("\t%s\n", pdp->depname);
 			}
 			free_deptree(&deptreehead);
 		}
@@ -218,6 +224,7 @@ show_full_dep_tree(const char *pkgname, const char *depquery, const char *msg)
 {
 	Pkgdeptree	*pdp;
 	Deptreehead	deptreehead; /* replacement for SLIST_HEAD() */
+	Pkglist		*mapplist;
 	int			count;
 	const char	*pkgquery;
 
@@ -230,6 +237,7 @@ show_full_dep_tree(const char *pkgname, const char *depquery, const char *msg)
 		errx(EXIT_FAILURE, MSG_EMPTY_AVAIL_PKGLIST);
 
 	count = count_samepkg(plisthead, pkgname);
+
 	/* free plisthead now so it is NULL for full_dep_tree() */
 	free_pkglist(plisthead);
 
@@ -240,8 +248,18 @@ show_full_dep_tree(const char *pkgname, const char *depquery, const char *msg)
 
 	printf(msg, pkgname);
 	full_dep_tree(pkgname, depquery, &deptreehead);
-	SLIST_FOREACH(pdp, &deptreehead, next)
-		printf("\t%s\n", pdp->depname);
 
+	/* record plisthead once again for map_pkg_to_dep() */
+	plisthead = rec_pkglist(pkgquery);
+
+	SLIST_FOREACH(pdp, &deptreehead, next) {
+		if (package_version && 
+			(mapplist = map_pkg_to_dep(plisthead, pdp->depname)) != NULL)
+			printf("\t%s\n", mapplist->pkgname);
+		else
+			printf("\t%s\n", pdp->depname);
+	}
+
+	free_pkglist(plisthead);
 	free_deptree(&deptreehead);
 }
